==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestGeneralActions.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

import de.fzj.unicore.ucc.UCC;
import de.fzj.unicore.ucc.util.EmbeddedTestBase;
import eu.unicore.bugsreporter.annotation.FunctionalTest;

/**
 * Functional tests for the UCC actions. 
 * These run against an embedded UNICORE instance.
 */
public class TestGeneralActions extends EmbeddedTestBase {
	
	@FunctionalTest(id="http://testHelp", description="Tests usage info printout")
	@Test
	public void test_Help(){
		UCC.main(new String[]{"help"});
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	@FunctionalTest(id="http://testCommandHelp", description="Tests usage info printout for single command")
	@Test
	public void test_CommandHelp(){
		UCC.main(new String[]{"connect", "-h"});
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	@FunctionalTest(id="http://testWrongSetup", description="Checks error message in case of bad security setup")
	@Test
	public void test_WrongSetup(){
		UCC.main(new String[]{"connect","-k","bad_keystore", 
				"-c", "src/test/resources/conf/userprefs.embedded",});
		assertEquals(Integer.valueOf(ActionBase.ERROR_SECURITY),UCC.exitCode);
	}

	@FunctionalTest(id="http://testWrongSetup2", description="Checks error message in case of missing registry")
	@Test
	public void test_WrongSetup_NoRegistry(){
		UCC.main(new String[]{"connect",
				"-c", "src/test/resources/conf/userprefs.noregistry",});
		assertEquals(Integer.valueOf(ActionBase.ERROR),UCC.exitCode);
	}

		
	@FunctionalTest(id="testListSites", description="Tests the list-sites command")
	@Test
	public void test_ListSites(){
		connect();
		String[] args=new String[]{"list-sites", "-v", "-l",
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		assertEquals(1,ListSites.getLastNumberOfResults());
	}

	@FunctionalTest(id="testListSitesFiltered", description="Tests the list-sites command using a filter")
	@Test
	public void test_ListSites_Filtered(){
		connect();
		String[] args=new String[]{"list-sites", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-f", "Name","contains","UCC"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testListApplications", description="Tests the list-applications command")
	@Test
	public void test_ListApplications(){
		connect();
		String[]args=new String[]{"list-applications", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		assertEquals(2,ListApplications.getLastNumberOfResults());
	}

	@FunctionalTest(id="testCreateStorage", description="Tests the create-storage command")
	@Test
	public void test_CreateStorage(){
		connect();

		String[] args=new String[]{"create-storage", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	@FunctionalTest(id="testCreateStorageParametrised", description="Tests the create-storage command with params")
	@Test
	public void test_CreateStorageParametrised(){
		connect();

		String[] args=new String[]{"create-storage", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-t", "DEFAULT", "testkey=testvalue"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	@FunctionalTest(id="testListStorages", description="Tests the list-storages command")
	@Test
	public void test_ListStorages(){
		connect();

		String[]args=new String[]{"list-storages", "-v", "-l",
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	
	@FunctionalTest(id="testWSRF", description="Tests the wsrf command")
	@Test
	public void test_WSRF(){
		connect();

		runDate();
		
		String id=Run.getLastJobAddress();
		
		String[] args=new String[]{"wsrf", "getproperties", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				id
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		args=new String[]{"wsrf", "extend","1", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				id,
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		args=new String[]{"wsrf", "destroy", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				id
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testSystemInfo", description="Tests the system-info command")
	@Test
	public void test_SystemInfo(){
		connect();
		String[] args=new String[]{"system-info",  
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		args=new String[]{"system-info", "-l",
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	
	@FunctionalTest(id="testShell", description="Tests the 'shell' command")
	@Test
	public void test_Shell()throws Exception{
		connect();
		String[]args=new String[]{"shell",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-f", "src/test/resources/shell_input",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testGroovy", description="Tests the 'groovy' command")
	@Test
	public void test_Groovy()throws Exception{
		connect();
		String[]args=new String[]{"run-groovy",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-f", "src/test/resources/groovy/test.groovy",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestGeneralActions.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import org.junit.Test;
import org.unigrids.x2006.x04.services.tsf.CreateTSRDocument;

import de.fzj.unicore.ucc.UCC;
import de.fzj.unicore.ucc.util.EmbeddedTestBase;
import eu.unicore.bugsreporter.annotation.FunctionalTest;

/**
 * Functional tests for the UCC actions. 
 * These run against an embedded UNICORE instance.
 */
public class TestGeneralActions extends EmbeddedTestBase {
	
	@FunctionalTest(id="http://testHelp", description="Tests usage info printout")
	@Test
	public void test_Help(){
		UCC.main(new String[]{"help"});
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		UCC.main(new String[]{"help-auth"});
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	@FunctionalTest(id="http://testCommandHelp", description="Tests usage info printout for single command")
	@Test
	public void test_CommandHelp(){
		UCC.main(new String[]{"connect", "-h"});
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	@FunctionalTest(id="http://testWrongSetup", description="Checks error message in case of bad security setup")
	@Test()
	public void test_WrongSetup(){
		UCC.main(new String[]{"connect","-k","NOSUCHAUTHN", 
				"-c", "src/test/resources/conf/userprefs.embedded",});
		assertEquals(Integer.valueOf(ActionBase.ERROR_SECURITY),UCC.exitCode);
	}

	@FunctionalTest(id="http://testWrongSetup2", description="Checks error message in case of missing registry")
	@Test
	public void test_WrongSetup_NoRegistry(){
		UCC.main(new String[]{"connect",
				"-c", "src/test/resources/conf/userprefs.noregistry",});
		assertEquals(Integer.valueOf(ActionBase.ERROR),UCC.exitCode);
	}

		
	@FunctionalTest(id="testListSites", description="Tests the list-sites command")
	@Test
	public void test_ListSites(){
		connect();
		String[] args=new String[]{"list-sites", "-v", "-l",
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		assertEquals(1,ListSites.getLastNumberOfResults());
	}

	@FunctionalTest(id="testListSitesFiltered", description="Tests the list-sites command using a filter")
	@Test
	public void test_ListSites_Filtered(){
		connect();
		String[] args=new String[]{"list-sites", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-f", "Name","contains","UCC"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testListApplications", description="Tests the list-applications command")
	@Test
	public void test_ListApplications(){
		connect();
		String[]args=new String[]{"list-applications", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		assertEquals(2,ListApplications.getLastNumberOfResults());
	}

	@FunctionalTest(id="testCreateTSS", description="Tests the create-tss command")
	@Test
	public void test_CreateTSS(){
		connect();

		String[] args=new String[]{"create-tss", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-l", "2",
				//extra parameters
				"testkey=testvalue"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		String lastTSS=CreateTSS.getLastTargetSystemAddress();
		assertNotNull(lastTSS);
		CreateTSRDocument tsr=CreateTSS.getLastCreateTSRDoc();
		assertEquals("testvalue", tsr.getCreateTSR().getTargetSystemDescription().getTextInfoArray(0).getValue());
	}
	
	
	@FunctionalTest(id="testCreateStorage", description="Tests the create-storage command")
	@Test
	public void test_CreateStorage(){
		connect();

		String[] args=new String[]{"create-storage", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-l", "2",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		//specifying factory URL
		args=new String[]{"create-storage", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-f", "http://localhost:65322/services/StorageFactory?res=default_storage_factory",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
	}
	
	@FunctionalTest(id="testCreateStorageParametrised", description="Tests the create-storage command with params")
	@Test
	public void test_CreateStorageParametrised(){
		connect();

		String[] args=new String[]{"create-storage", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-t", "DEFAULT", "testkey=testvalue"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	@FunctionalTest(id="testListStorages", description="Tests the list-storages command")
	@Test
	public void test_ListStorages(){
		connect();

		String[]args=new String[]{"list-storages", "-v", "-l",
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	
	@FunctionalTest(id="testWSRF", description="Tests the wsrf command")
	@Test
	public void test_WSRF(){
		connect();

		runDate();
		
		String id=Run.getLastJobAddress();
		
		String[] args=new String[]{"wsrf", "getproperties", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				id
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		args=new String[]{"wsrf", "extend","1", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				id,
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		args=new String[]{"wsrf", "destroy", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				id
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testSystemInfo", description="Tests the system-info command")
	@Test
	public void test_SystemInfo(){
		connect();
		String[] args=new String[]{"system-info",  
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		args=new String[]{"system-info", "-l",
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	
	@FunctionalTest(id="testShell", description="Tests the 'shell' command")
	@Test
	public void test_Shell()throws Exception{
		connect();
		String[]args=new String[]{"shell",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-f", "src/test/resources/shell_input",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testGroovy", description="Tests the 'groovy' command")
	@Test
	public void test_Groovy()throws Exception{
		connect();
		String[]args=new String[]{"run-groovy",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-f", "src/test/resources/groovy/test.groovy",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

}
